﻿'***********************************************************************************
' Author: RWB
' Created: 28/06/2012 4:15:35 PM
'***********************************************************************************

Public Class frmMain
    Dim WithEvents comPort As New IO.Ports.SerialPort
    Dim cMsgCaption As String

    Private Sub frmMain_FormClosing(sender As Object, e As FormClosingEventArgs) Handles Me.FormClosing
        Try
            comPort.Close()            
        Catch ex As Exception
            MsgBox(ex.ToString, MsgBoxStyle.Information, cMsgCaption)
        End Try
    End Sub

    Private Sub frmMain_Load(sender As Object, e As EventArgs) Handles Me.Load
        Dim i As Integer

        ' Assign default Caption
        cMsgCaption = "I2C BlueTooth Control"

        ' List the Available Port
        For i = 0 To My.Computer.Ports.SerialPortNames.Count - 1
            cboCom.Items.Add(My.Computer.Ports.SerialPortNames(i))
        Next

        ' Analog Sensor Status
        cboAnalog.Items.Add("Off")
        cboAnalog.Items.Add("On")
        cboAnalog.SelectedIndex = 0

        ' Select the First Index
        cboCom.SelectedIndex = 0
        cboBaud.SelectedIndex = 0
        cboDuration.SelectedIndex = 0
        cboEncoder.SelectedIndex = 0
        txtStatus.Text = "Diconnected"        
    End Sub

    Private Sub btnConnect_Click(sender As Object, e As EventArgs) Handles btnConnect.Click
        ' Check COM Port if open then close
        If comPort.IsOpen Then
            comPort.Close()
        End If

        ' Now Connect the COM Port        
        Try
            With comPort
                .ReadTimeout = 10000
                .PortName = cboCom.Text
                .BaudRate = cboBaud.Text
                .Parity = IO.Ports.Parity.None
                .DataBits = 8
                .StopBits = IO.Ports.StopBits.One
            End With

            ' Opening the COM Port
            comPort.Open()
            txtStatus.Text = "Connected to " & cboCom.Text & " at " & cboBaud.Text

            ' Set the Default Power
            If comPort.IsOpen Then                
                comPort.Write("P" & trbPower.Value.ToString & vbCr)
            End If

            btnConnect.Enabled = False
            btnDisconnect.Enabled = True
        Catch ex As Exception
            MsgBox(ex.ToString, MsgBoxStyle.Information, cMsgCaption)
        End Try
    End Sub

    Private Sub btnDisconnect_Click(sender As Object, e As EventArgs) Handles btnDisconnect.Click       
        Try
            comPort.Close()
            txtStatus.Text = "Diconnected"
            btnConnect.Enabled = True
            btnDisconnect.Enabled = False
        Catch ex As Exception
            MsgBox(ex.ToString, MsgBoxStyle.Information, cMsgCaption)
        End Try
    End Sub

    Private Sub btnForward_Click(sender As Object, e As EventArgs) Handles btnForward.Click
        If comPort.IsOpen Then
            rtbResponse.AppendText("Forward..." & vbCr)
            rtbResponse.ScrollToCaret()
            comPort.Write("S1" & vbCr)
        End If
    End Sub

    Private Sub btnBreak_Click(sender As Object, e As EventArgs) Handles btnBreak.Click
        If comPort.IsOpen Then
            rtbResponse.AppendText("Break..." & vbCr)
            rtbResponse.ScrollToCaret()
            comPort.Write("B" & vbCr)
        End If
    End Sub

    Private Sub btnRRight_Click(sender As Object, e As EventArgs) Handles btnRRight.Click
        If comPort.IsOpen Then
            rtbResponse.AppendText("Rotate Right..." & vbCr)
            rtbResponse.ScrollToCaret()
            comPort.Write("S6" & vbCr)
        End If
    End Sub

    Private Sub btnRight_Click(sender As Object, e As EventArgs) Handles btnRight.Click
        If comPort.IsOpen Then
            rtbResponse.AppendText("Turn Right..." & vbCr)
            rtbResponse.ScrollToCaret()
            comPort.Write("S4" & vbCr)
        End If
    End Sub

    Private Sub btnLeft_Click(sender As Object, e As EventArgs) Handles btnLeft.Click
        If comPort.IsOpen Then
            rtbResponse.AppendText("Turn Left..." & vbCr)
            rtbResponse.ScrollToCaret()
            comPort.Write("S5" & vbCr)
        End If
    End Sub

    Private Sub btnRLeft_Click(sender As Object, e As EventArgs) Handles btnRLeft.Click
        If comPort.IsOpen Then
            rtbResponse.AppendText("Rotate Left..." & vbCr)
            rtbResponse.ScrollToCaret()
            comPort.Write("S7" & vbCr)
        End If
    End Sub

    Private Sub btnBackward_Click(sender As Object, e As EventArgs) Handles btnBackward.Click
        If comPort.IsOpen Then
            rtbResponse.AppendText("Backward..." & vbCr)
            rtbResponse.ScrollToCaret()
            comPort.Write("S2" & vbCr)
        End If
    End Sub

    Private Sub cboDuration_SelectedIndexChanged(sender As Object, e As EventArgs) Handles cboDuration.SelectedIndexChanged
        Dim strDuration As String

        strDuration = "D0"
        Select Case cboDuration.Text
            Case "Unlimited"
                strDuration = "D0"
            Case "Second"
                strDuration = "D1"
            Case "Rotation"
                strDuration = "D2"
            Case "Degree"
                strDuration = "D3"
        End Select

        If comPort.IsOpen Then
            comPort.Write(strDuration & vbCr)
        End If
    End Sub

    Private Sub cboEncoder_SelectedIndexChanged(sender As Object, e As EventArgs) Handles cboEncoder.SelectedIndexChanged
        Dim strEncoder As String

        strEncoder = "E0"
        Select Case cboEncoder.Text
            Case "Left Wheel"
                strEncoder = "E0"
            Case "Right Wheel"
                strEncoder = "E1"
        End Select

        If comPort.IsOpen Then
            comPort.Write(strEncoder & vbCr)
        End If
    End Sub

    Private Sub comPort_DataReceived(sender As Object, e As IO.Ports.SerialDataReceivedEventArgs) Handles comPort.DataReceived
        rtbResponse.Invoke(New comReceiveDelegate(AddressOf updateTextBox), New Object() {})
    End Sub

    Public Delegate Sub comReceiveDelegate()
    Public Sub updateTextBox()
        Dim strResponse As String       

        strResponse = comPort.ReadTo("CTRL>").Trim.Substring(1)
        If strResponse.IndexOf("Error") > 0 Then
            rtbResponse.AppendText("Command Error!" & vbCrLf)
        Else
            If cboAnalog.SelectedIndex = 1 Then
                If strResponse.Length > 0 Then
                    tbSensor.Text = strResponse
                End If
            End If

            rtbResponse.AppendText("Ok" & vbCrLf)
            rtbResponse.ScrollToCaret()
        End If
    End Sub

    Private Sub trbPower_Scroll(sender As Object, e As EventArgs) Handles trbPower.Scroll
        lblPower.Text = trbPower.Value.ToString
        If comPort.IsOpen Then
            rtbResponse.AppendText("Power " & trbPower.Value.ToString & "..." & vbCr)
            rtbResponse.ScrollToCaret()
            comPort.Write("P" & trbPower.Value.ToString & vbCr)
            System.Threading.Thread.Sleep(5)
        End If
    End Sub

    Private Sub trbArching_Scroll(sender As Object, e As EventArgs) Handles trbArching.Scroll
        Dim intArching As Integer

        lblArching.Text = trbArching.Value.ToString
        intArching = trbArching.Value + 100
        If comPort.IsOpen Then            
            rtbResponse.AppendText("Arching " & intArching.ToString & "..." & vbCr)
            rtbResponse.ScrollToCaret()
            comPort.Write("A" & intArching.ToString & vbCr)
            System.Threading.Thread.Sleep(5)
        End If
    End Sub

    Private Sub trbDuration_Scroll(sender As Object, e As EventArgs) Handles trbDuration.Scroll
        If comPort.IsOpen Then
            rtbResponse.AppendText("Duration " & trbDuration.Value.ToString & "..." & vbCr)
            rtbResponse.ScrollToCaret()
            comPort.Write("L" & trbDuration.Value.ToString & vbCr)
            System.Threading.Thread.Sleep(5)
        End If
    End Sub

    Private Sub btnCenter_Click(sender As Object, e As EventArgs) Handles btnCenter.Click
        Dim intArching As Integer

        trbArching.Value = 0
        lblArching.Text = trbArching.Value.ToString
        intArching = trbArching.Value + 100
        If comPort.IsOpen Then
            rtbResponse.AppendText("Center..." & vbCrLf)
            rtbResponse.ScrollToCaret()
            comPort.Write("A" & intArching.ToString & vbCr)
            System.Threading.Thread.Sleep(5)
        End If
    End Sub

    Private Sub btnARight_Click(sender As Object, e As EventArgs) Handles btnARight.Click
        Dim intArching As Integer

        trbArching.Value = 60
        lblArching.Text = trbArching.Value.ToString
        intArching = trbArching.Value + 100
        If comPort.IsOpen Then
            rtbResponse.AppendText("Arch Right..." & vbCr)
            rtbResponse.ScrollToCaret()
            comPort.Write("A" & intArching.ToString & vbCr)
            System.Threading.Thread.Sleep(5)
        End If
    End Sub

    Private Sub btnALeft_Click(sender As Object, e As EventArgs) Handles btnALeft.Click
        Dim intArching As Integer

        trbArching.Value = -40
        lblArching.Text = trbArching.Value.ToString
        intArching = trbArching.Value + 100
        If comPort.IsOpen Then
            rtbResponse.AppendText("Arch Left..." & vbCr)
            rtbResponse.ScrollToCaret()
            comPort.Write("A" & intArching.ToString & vbCr)
            System.Threading.Thread.Sleep(5)
        End If
    End Sub

    Private Sub btnClear_Click(sender As Object, e As EventArgs) Handles btnClear.Click
        ' Clear Response Log
        rtbResponse.Text = ""
    End Sub

    Private Sub cboAnalog_SelectedIndexChanged(sender As Object, e As EventArgs) Handles cboAnalog.SelectedIndexChanged
        If comPort.IsOpen Then
            If cboAnalog.SelectedIndex = 1 Then                
                tmAnalog.Enabled = True
                tbSensor.Text = ""
                comPort.Write("N1" & vbCr)
            Else
                tmAnalog.Enabled = False
                tbSensor.Text = ""
                comPort.Write("N0" & vbCr)
            End If
            System.Threading.Thread.Sleep(5)
        End If
    End Sub

    Private Sub tmAnalog_Tick(sender As Object, e As EventArgs) Handles tmAnalog.Tick
        If comPort.IsOpen Then
            comPort.Write("R" & vbCr)            
        End If
    End Sub

    Private Sub trbServo_Scroll(sender As Object, e As EventArgs) Handles trbServo.Scroll
        Dim intServo As Integer

        lblServo.Text = trbServo.Value.ToString
        intServo = 100 - trbServo.Value
        If comPort.IsOpen Then
            rtbResponse.AppendText("Servo " & intServo.ToString & "..." & vbCr)
            rtbResponse.ScrollToCaret()
            comPort.Write("O" & intServo.ToString & vbCr)
            System.Threading.Thread.Sleep(5)
        End If
    End Sub

    Private Sub btnServoCenter_Click(sender As Object, e As EventArgs) Handles btnServoCenter.Click
        Dim intServo As Integer

        trbServo.Value = 50
        lblServo.Text = trbServo.Value.ToString
        intServo = trbServo.Value
        If comPort.IsOpen Then
            rtbResponse.AppendText("Servo Center..." & vbCrLf)
            rtbResponse.ScrollToCaret()
            comPort.Write("O" & intServo.ToString & vbCr)
            System.Threading.Thread.Sleep(5)
        End If
    End Sub

    Private Sub btnServoLeft_Click(sender As Object, e As EventArgs) Handles btnServoLeft.Click
        Dim intServo As Integer

        trbServo.Value = 0
        lblServo.Text = trbServo.Value.ToString
        intServo = 100 - trbServo.Value
        If comPort.IsOpen Then
            rtbResponse.AppendText("Servo Left..." & vbCrLf)
            rtbResponse.ScrollToCaret()
            comPort.Write("O" & intServo.ToString & vbCr)
            System.Threading.Thread.Sleep(5)
        End If
    End Sub

    Private Sub btnServoRight_Click(sender As Object, e As EventArgs) Handles btnServoRight.Click
        Dim intServo As Integer

        trbServo.Value = 100
        lblServo.Text = trbServo.Value.ToString
        intServo = 100 - trbServo.Value
        If comPort.IsOpen Then
            rtbResponse.AppendText("Servo Right..." & vbCrLf)
            rtbResponse.ScrollToCaret()
            comPort.Write("O" & intServo.ToString & vbCr)
            System.Threading.Thread.Sleep(5)
        End If
    End Sub
End Class
